@@ -66,6 +66,9 @@ sorted_classifiers: List[str] = [
     "Environment :: Web Environment :: Buffet",
     "Environment :: Web Environment :: Mozilla",
     "Environment :: Web Environment :: ToscaWidgets",
+    "Environment :: WebAssembly",
+    "Environment :: WebAssembly :: Emscripten",
+    "Environment :: WebAssembly :: WASI",
     "Environment :: Win32 (MS Windows)",
     "Environment :: X11 Applications",
     "Environment :: X11 Applications :: GTK",
@@ -117,6 +120,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Django :: 4",
     "Framework :: Django :: 4.0",
     "Framework :: Django :: 4.1",
+    "Framework :: Django :: 4.2",
     "Framework :: Django CMS",
     "Framework :: Django CMS :: 3.4",
     "Framework :: Django CMS :: 3.5",
@@ -179,7 +183,10 @@ sorted_classifiers: List[str] = [
     "Framework :: Plone :: 6.0",
     "Framework :: Plone :: Addon",
     "Framework :: Plone :: Core",
+    "Framework :: Plone :: Distribution",
     "Framework :: Plone :: Theme",
+    "Framework :: Pydantic",
+    "Framework :: Pydantic :: 1",
     "Framework :: Pylons",
     "Framework :: Pyramid",
     "Framework :: Pytest",
